Python API reference
====================


.. currentmodule:: geouned

.. autoclass:: CsgToCad
    :members:
    :show-inheritance:

.. autoclass:: CadToCsg
    :members:
    :show-inheritance:

.. autoclass:: NumericFormat
    :members:
    :show-inheritance:

.. autoclass:: Options
    :members:
    :show-inheritance:

.. autoclass:: Settings
    :members:
    :show-inheritance:

.. autoclass:: Tolerances
    :members:
    :show-inheritance: